RoomConnectionState enum

Room connection states

Inheritance
Available extensions

Values

disconnected → const RoomConnectionState

Not connected to a room

connecting → const RoomConnectionState

Connecting to a room

connected → const RoomConnectionState

Connected to a room

reconnecting → const RoomConnectionState

Reconnecting after losing connection

failed → const RoomConnectionState

Connection failed

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RoomConnectionState>
A constant List of the values in this enum, in order of their declaration.