ScreenSharingState enum

State of the screen sharing session

Inheritance
Available extensions

Values

inactive → const ScreenSharingState

Not currently sharing

starting → const ScreenSharingState

In the process of starting screen sharing

active → const ScreenSharingState

Actively sharing the screen

stopping → const ScreenSharingState

In the process of stopping screen sharing

error → const ScreenSharingState

An error occurred during screen sharing

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ScreenSharingState>
A constant List of the values in this enum, in order of their declaration.