ScreenSharingService class
Service for managing screen sharing
- Implemented types
Constructors
- ScreenSharingService()
- Create a new screen sharing service
Properties
- audioTrack → MediaStreamTrack?
-
Get the screen sharing audio track if active and capturing audio
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → ScreenSharingOptions
-
Get the current screen sharing options
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenStream → MediaStream?
-
Get the screen sharing stream if active
no setter
- screenTrack → MediaStreamTrack?
-
Get the screen sharing video track if active
no setter
- state → ScreenSharingState
-
Get the current state of screen sharing
no setter
Methods
-
addStateListener(
ScreenSharingStateCallback listener) → void - Register a callback for screen sharing state changes
-
dispose(
) → Future< void> -
Releases resources held by this object
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeStateListener(
ScreenSharingStateCallback listener) → void - Remove a previously registered state change callback
-
startScreenSharing(
{ScreenSharingOptions? options}) → Future< Result< MediaStream, VibecallError> > - Start sharing the screen
-
stopScreenSharing(
) → Future< Result< bool, VibecallError> > - Stop sharing the screen
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited