VirtualBackgroundProcessor class
Processor for applying virtual background effects to camera frames
This class uses a segmentation mask to separate the foreground (person) from the background and applies various effects to the background.
- Implemented types
Constructors
- VirtualBackgroundProcessor({required SegmentationService segmentationService, BackgroundOptions options = const BackgroundOptions(), BufferPool? bufferPool})
- Create a virtual background processor
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → BackgroundOptions
-
Get the current background options
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Releases resources held by this object
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processFrame(
CameraFrame frame) → Future< Result< CameraFrame, VibecallError> > - Process a camera frame to apply the virtual background effect
-
setOptions(
BackgroundOptions options) → Future< void> - Set new background options
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited